@@ -71,7 +71,7 @@ PhraseList::PhraseList(QWidget *parent, const QString &name) : QWidget(parent)
     configureCompletionCombo(completion->wordLists());
     rowLayout->addWidget(dictionaryCombo);
 
-    lineEdit = new KLineEdit(QLatin1String(""), this);
+    lineEdit = new KLineEdit(this);
     lineEdit->setFocusPolicy(Qt::StrongFocus);
     lineEdit->setFrame(true);
     lineEdit->setEchoMode(QLineEdit::Normal);
@@ -88,16 +88,12 @@ PhraseList::PhraseList(QWidget *parent, const QString &name) : QWidget(parent)
     speakButton->setWhatsThis(i18n("Speaks the currently active sentence(s). If there is some text in the edit field it is spoken. Otherwise the selected sentences in the history (if any) are spoken."));
     rowLayout->addWidget(speakButton);
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-    connect(dictionaryCombo, QOverload<const QString &>::of(&KComboBox::activated), completion, &WordCompletion::setWordList);
-#else
     connect(dictionaryCombo, QOverload<const QString &>::of(&KComboBox::textActivated), completion, &WordCompletion::setWordList);
-#endif
     connect(completion, &WordCompletion::wordListsChanged, this, &PhraseList::configureCompletionCombo);
 
     connect(m_listView->selectionModel(),  &QItemSelectionModel::selectionChanged, this, &PhraseList::selectionChanged);
     connect(m_listView,  &QWidget::customContextMenuRequested, this, &PhraseList::contextMenuRequested);
-    connect(lineEdit, &KLineEdit::returnPressed, this, &PhraseList::lineEntered);
+    connect(lineEdit, &KLineEdit::returnKeyPressed, this, &PhraseList::lineEntered);
     connect(lineEdit, &QLineEdit::textChanged, this, &PhraseList::textChanged);
     connect(speakButton, &QAbstractButton::clicked, this, &PhraseList::speak);
 }
